package
Version:
v0.0.0-...-f8e8671
Opens a new window with list of versions in this module.
Published: Sep 8, 2022
License: MIT
Opens a new window with license information.
Imports: 15
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
SetupRoutes will setup all routes in systems. Sub routs will be manage details by setupXXX function
type GetSecretRequest struct {
Region string `json:"region"`
Arn string `json:"arn"`
}
type ListSecretRequest struct {
Region string `json:"region"`
}
type UserLogin struct {
Username string `json:"username" form:"username"`
Password string `json:"password" form:"password"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.